@@ -376,7 +376,7 @@ def TransferTask(
   agglomerate=False,
   timestamp=None,
   compress='gzip',
-  factor=None
+  factor=None,
 ):
   """
   Transfer an image to a new location while enabling
@@ -400,7 +400,7 @@ def TransferTask(
   dest_cv = CloudVolume(
     dest_path, fill_missing=fill_missing,
     mip=mip, delete_black_uploads=delete_black_uploads,
-    background_color=background_color, compress=compress
+    background_color=background_color, compress=compress,
   )
 
   dst_bbox = Bbox(offset, shape + offset)
@@ -504,7 +504,7 @@ def ImageShardTransferTask(
     dst_path,
     fill_missing=fill_missing,
     mip=mip,
-    compress=None
+    compress=None,
   )
 
   dst_bbox = Bbox(offset, offset + shape)
