@@ -64,7 +64,7 @@ class CloudPath(click.ParamType):
 
 @click.group()
 @click.option("-p", "--parallel", default=1, help="Run with this number of parallel processes. If 0, use number of cores.")
-@click.version_option(version="4.10.0")
+@click.version_option(version="4.11.0")
 @click.pass_context
 def main(ctx, parallel):
   """
@@ -708,10 +708,13 @@ def meshgroup():
 @click.option("--sharded", is_flag=True, default=False, help="Generate shard fragments instead of outputing mesh fragments.", show_default=True)
 @click.option("--dir", "mesh_dir", type=str, default=None, help="Write meshes into this directory instead of the one indicated in the info file.")
 @click.option('--magnitude', default=2, help="Split up the work with 10^(magnitude) prefix based tasks.", show_default=True)
+@click.option('--mip', type=int, default=None, help="Manually specify which mip level the images were derived from.", show_default=True)
+@click.option('--nlod', type=int, default=0, help="(sharded) Create additional levels of detail (lods).", show_default=True)
 @click.pass_context
 def mesh_xfer(
   ctx, src, dest, queue,
-  sharded, mesh_dir, magnitude
+  sharded, mesh_dir, magnitude,
+  mip, nlod
 ):
   """
   Transfer meshes to another location.
@@ -723,8 +726,9 @@ def mesh_xfer(
   if not cv_src.mesh.meta.is_sharded() and sharded:
     tasks = tc.create_sharded_multires_mesh_from_unsharded_tasks(
       src, dest,
-      num_lod=0, 
+      num_lod=nlod, 
       mesh_dir=mesh_dir, 
+      mip=mip,
     )
   else:
     tasks = tc.create_xfer_meshes_tasks(
@@ -795,7 +799,7 @@ def mesh_forge(
 @click.option('--magnitude', default=2, help="Split up the work with 10^(magnitude) prefix based tasks. Default: 2 (100 tasks)")
 @click.option('--nlod', default=0, help="(multires) How many extra levels of detail to create.", show_default=True)
 @click.option('--vqb', default=16, help="(multires) Vertex quantization bits for stored model representation. 10 or 16 only.", show_default=True)
-@click.option('--min-chunk-size', type=Tuple3(), default="512,512,512",  help="(multires) Sets the minimum chunk size of the highest resolution mesh fragment.", show_default=True)
+@click.option('--min-chunk-size', type=Tuple3(), default="256,256,256",  help="(multires) Sets the minimum chunk size of the highest resolution mesh fragment.", show_default=True)
 @click.option('--dir', default=None, help="Write manifests into this directory instead of the one indicated in the info file.")
 @click.pass_context
 def mesh_merge(ctx, path, queue, magnitude, nlod, vqb, dir, min_chunk_size):
@@ -835,7 +839,7 @@ def mesh_merge(ctx, path, queue, magnitude, nlod, vqb, dir, min_chunk_size):
 @click.option('--max-labels-per-shard', default=1000, help="Maximum average number of labels per a shard.", type=int, show_default=True)
 @click.option('--minishard-index-encoding', default="gzip", help="Minishard indices can be compressed. gzip or raw.", show_default=True)
 @click.option('--spatial-index-db', default=None, help="CloudVolume generated SQL database for spatial index.", show_default=True)
-@click.option('--min-chunk-size', type=Tuple3(), default="512,512,512",  help="(multires) Sets the minimum chunk size of the highest resolution mesh fragment.", show_default=True)
+@click.option('--min-chunk-size', type=Tuple3(), default="256,256,256",  help="(multires) Sets the minimum chunk size of the highest resolution mesh fragment.", show_default=True)
 @click.pass_context
 def mesh_sharded_merge(
   ctx, path, queue, 
